// Define the trigger pin for the ultrasonic sensor
#define TRIG_PIN 2

// Include required libraries
#include <SoftwareSerial.h>
#include <DFRobotDFPlayerMini.h>
#include <Servo.h>
#include <NewPing.h>

// Define the echo pin for the ultrasonic sensor, and the servo pins for the 3 servos
#define ECHO_PIN 3
#define ULTRASONIC_SERVO_PIN 9
int pos1 = 90;
int pos2 = 90;
int pos3 = 90;
#define NOSE_SERVO_PIN 6
#define EYE_SERVO_PIN 5
#define NOSE_TOUCH_PIN 7
#define EYE_TOUCH_PIN 8

// Define the maximum distance the ultrasonic sensor can detect
#define MAX_DISTANCE 200

// Create a software serial object to communicate with the DFPlayer module
SoftwareSerial mySoftwareSerial(11, 10); // RX, TX

// Create a DFPlayer object
DFRobotDFPlayerMini myDFPlayer;

// Create servo objects for the 3 servos
Servo ultrasonicServo;
Servo noseServo;
Servo eyeServo;

// Create a NewPing object for the ultrasonic sensor
NewPing sonar(TRIG_PIN, ECHO_PIN, MAX_DISTANCE);

// Code in the setup function runs once at the start of the program
void setup() {

  // Start serial communication at a baud rate of 115200
  Serial.begin(115200);

  // Start software serial communication at a baud rate of 9600
  mySoftwareSerial.begin(9600);

  // Start communication with the DFPlayer module
  myDFPlayer.begin(mySoftwareSerial);

  // Volume for the DFPlayer
  myDFPlayer.volume(25);  //Set volume value. From 0 to 30
  // myDFPlayer.play(1);  //Play the first mp3

  // Attach the ultrasonic servo to its pin
  ultrasonicServo.attach(ULTRASONIC_SERVO_PIN);

  // Attach the nose servo to its pin
  noseServo.attach(NOSE_SERVO_PIN);
  noseServo.write(90);

  // Attach the eye servo to its pin
  eyeServo.attach(EYE_SERVO_PIN);
  eyeServo.write(90);
}

// Code in the loop function runs repeatedly after setup is complete
void loop() {
  if (digitalRead(NOSE_TOUCH_PIN) == HIGH) {  
    Serial.println("nose servo run by touch_nose_sensor");
  for (int pos2 = 90; pos2 >= 45; pos2 -= 1) {
    noseServo.write(pos2);
    delay(25);
  }  
  for (int pos2 = 45; pos2 <= 135; pos2 += 1) {
    noseServo.write(pos2);
    delay(25);
  }  
  for (int pos2 = 135; pos2 >= 90; pos2 -= 1) {
    noseServo.write(pos2);
    delay(25); 
  } 
  noseServo.write(90);
  delay(25);
      
  }


// }


if (digitalRead(EYE_TOUCH_PIN) == HIGH) { 
      myDFPlayer.play(4);

    for (int pos3 = 60; pos3 >= 0; pos3 -= 1) {       
      eyeServo.write(pos3);
      delay(15);
  }
      myDFPlayer.play(4)
    for (int pos3 = 0; pos3 <= 120; pos3 += 1) { 
      Serial.println("eye servo run by touch_eye_sensor");
      eyeServo.write(pos3);
      delay(15);      
    }


    for (int pos3 = 120; pos3 >= 60; pos3 -= 1) { 
      Serial.println("eye servo run by touch_eye_sensor");
      eyeServo.write(pos3);
      delay(15);  
    }
  }

  int distance = sonar.ping_cm();
  
  if (distance > 0 && distance < 15) {
        myDFPlayer.play(3);

    // Set the ultrasonic servo motor to move in a pattern
      if (distance > 0 && distance < 5) {
      
    for (pos1 = 90; pos1 <= 120; pos1 += 1) {
      ultrasonicServo.write(pos1); // "Hey"
      delay(35);
    }
    for (pos1 = 120; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // "Hey"
      delay(75);
    }
    
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1); // "So"
      delay(45);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // "so"
      delay(45);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1); // "much"
      delay(45);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // "much"
      delay(25);
    }
       
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1); // 
      delay(45);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // 
      delay(45);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1); // 
      delay(45);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); //
      delay(25);
    }
    for (pos1 = 90; pos1 <= 140; pos1 += 10) {
      ultrasonicServo.write(pos1); // "to"
      delay(35);
    }
    for (pos1 = 140; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // "to"
      delay(35);
    }
    for (pos1 = 90; pos1 <= 120; pos1 += 10) {
      ultrasonicServo.write(pos1); // "learn"
      delay(55);
    }
    for (pos1 = 120; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // "learn"
      delay(40);
    }
    for (pos1 = 90; pos1 <= 110; pos1 += 10) {
      ultrasonicServo.write(pos1); // "A.."
      delay(35);
    }
    for (pos1 = 110; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // "...A"
      delay(20);
    }
    for (pos1 = 90; pos1 <= 100; pos1 += 10) {
      ultrasonicServo.write(pos1); // "bo..."
      delay(35);
    }
    for (pos1 = 100; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // "....bo"
      delay(40);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1); // "t"
      delay(35);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // "...t"
      delay(35);
    }
    for (pos1 = 120; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // it
      delay(35);
    }
    for (pos1 = 90; pos1 <= 140; pos1 += 10) {
      ultrasonicServo.write(pos1); // will
      delay(35);
    }
    for (pos1 = 140; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // will
      delay(45);
    }
    for (pos1 = 90; pos1 <= 110; pos1 += 10) {
      ultrasonicServo.write(pos1); // make
      delay(45);
    }
    for (pos1 = 110; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // make
      delay(35);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1); // you
      delay(45);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // you
      delay(35);
    }
    for (pos1 = 90; pos1 <= 120; pos1 += 10) {
      ultrasonicServo.write(pos1); // wanna
      delay(55);
    }
    for (pos1 = 120; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // wanna
      delay(35);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1); // shout
      delay(55);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // shout
      delay(35);
    }
    for (pos1 = 90; pos1 <= 140; pos1 += 10) {
      ultrasonicServo.write(pos1); // Bli
      delay(35);
    }
    for (pos1 = 140; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // Bli
      delay(45);
    }
    for (pos1 = 90; pos1 <= 140; pos1 += 10) {
      ultrasonicServo.write(pos1); // ppi
      delay(35);
    }
    for (pos1 = 140; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); // ppi
      delay(40);
    }
    for (pos1 = 90; pos1 <= 120; pos1 += 10) {
      ultrasonicServo.write(pos1); // I
      delay(25);
    }
    for (pos1 = 120; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1);// am
      delay(35);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1);// so
      delay(35);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1);//So
      delay(5);
    }
    for (pos1 = 90; pos1 <= 120; pos1 += 10) {
      ultrasonicServo.write(pos1);//exited
      delay(50);
    }
    for (pos1 = 120; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1);// exited
      delay(40);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1);// to
      delay(35);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1);// to
      delay(35);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1);// go
      delay(35);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1);// go
      delay(35);
    }
    for (pos1 = 90; pos1 <= 140; pos1 += 10) {
      ultrasonicServo.write(pos1);//onn
      delay(35);
    }
    for (pos1 = 140; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1); //onn
      delay(25);
    }
    for (pos1 = 90; pos1 <= 120; pos1 += 10) {
      ultrasonicServo.write(pos1);//so
      delay(45);
    }
    for (pos1 = 120; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1);// so
      delay(25);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1);// many
      delay(45);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1);//many
      delay(45);
    }
    for (pos1 = 90; pos1 <= 130; pos1 += 10) {
      ultrasonicServo.write(pos1);// fun
      delay(35);
    }
    for (pos1 = 130; pos1 >= 90; pos1 -= 10) {
      ultrasonicServo.write(pos1);//fun
      delay(35);
    }
    for (int pos1 = 90; pos1 <= 140; pos1 += 10) {
     ultrasonicServo.write(pos1);// ADVEN
     delay(50);
    }
    for (int pos1 = 140; pos1 >= 90; pos1 -= 10) {
     ultrasonicServo.write(pos1);//TURE..
     delay(50);
    }
    
    }

  }
  
}


